package com.ruoyi.app2.controller;

import com.ruoyi.app2.domain.PostAppSeries;
import com.ruoyi.app2.service.PostAppSeriesService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 邮贝套系信息Controller
 * 
 * @author ruoyi
 * @date 2023-03-10
 */
@RestController
@RequestMapping("/system/series")
public class PostAppSeriesController extends BaseController
{
    @Resource
    private PostAppSeriesService PostAppSeriesService;

    /**
     * 查询邮贝套系信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:series:list')")
    @GetMapping("/list")
    public TableDataInfo list(PostAppSeries PostAppSeries)
    {
        startPage();
        List<PostAppSeries> list = PostAppSeriesService.selectPostAppSeriesList(PostAppSeries);
        return getDataTable(list);
        /*startPage();
        List<PostAppSeries> list = PostAppSeriesService.selectPostAppSeriesList(PostAppSeries);
        return getDataTable(list);*/
//      return PostAppSeriesMapper.selectPostAppSeriesList(PostAppSeries);
    }


    /**
     * 导出邮贝套系信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:series:export')")
    @Log(title = "邮贝套系信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PostAppSeries PostAppSeries)
    {
        List<PostAppSeries> list = PostAppSeriesService.selectPostAppSeriesList(PostAppSeries);
        ExcelUtil<PostAppSeries> util = new ExcelUtil<PostAppSeries>(PostAppSeries.class);
        util.exportExcel(response, list, "邮贝套系信息数据");
    }

    /**
     * 获取邮贝套系信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:series:query')")
    @GetMapping(value = "/{seriesId}")
    public AjaxResult getInfo(@PathVariable("seriesId") Long seriesId)
    {
        return success(PostAppSeriesService.selectPostAppSeriesBySeriesId(seriesId));
    }

    /**
     * 新增邮贝套系信息
     */
    @PreAuthorize("@ss.hasPermi('system:series:add')")
    @Log(title = "邮贝套系信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    public AjaxResult add(@RequestBody PostAppSeries PostAppSeries)
    {
        return toAjax(PostAppSeriesService.insertPostAppSeries(PostAppSeries));
    }

    /**
     * 修改邮贝套系信息
     */
    @PreAuthorize("@ss.hasPermi('system:series:edit')")
    @Log(title = "邮贝套系信息", businessType = BusinessType.UPDATE)
    @PutMapping("/update")
    public AjaxResult edit(@RequestBody PostAppSeries PostAppSeries)
    {
        return toAjax(PostAppSeriesService.updatePostAppSeries(PostAppSeries));
    }

    /**
     * 删除邮贝套系信息
     */
    @PreAuthorize("@ss.hasPermi('system:series:remove')")
    @Log(title = "邮贝套系信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{seriesIds}")
    public AjaxResult remove(@PathVariable Long[] seriesIds)
    {
        return toAjax(PostAppSeriesService.deletePostAppSeriesBySeriesIds(seriesIds));
    }
}
