package com.ruoyi.app2.controller;

import com.ruoyi.app2.domain.Publisher;
import com.ruoyi.app2.service.IPublisherService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

@RestController
@Slf4j
@RequestMapping("/pp")
public class PublisherController extends BaseController {
    @Autowired
    private IPublisherService iPublisherService;



    /**
     * 查询邮贝发行方信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:publisher:list')")
    @GetMapping("/list")
    public TableDataInfo list(Publisher publisher)
    {
        startPage();
        List<Publisher> list = iPublisherService.selectPostPublisherList(publisher);
        return getDataTable(list);
    }

    /**
     * 导出邮贝发行方信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:publisher:export')")
    @Log(title = "邮贝发行方信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Publisher postPublisher)
    {
        List<Publisher> list = iPublisherService.selectPostPublisherList(postPublisher);
        ExcelUtil<Publisher> util = new ExcelUtil<Publisher>(Publisher.class);
        util.exportExcel(response, list, "邮贝发行方信息数据");
    }

    /**
     * 获取邮贝发行方信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:publisher:query')")
    @GetMapping(value = "/{publisherId}")
    public AjaxResult getInfo(@PathVariable("publisherId") Long publisherId)
    {
        return success(iPublisherService.selectPostPublisherByPublisherId(publisherId));
    }

    /**
     * 新增邮贝发行方信息
     */
    @PreAuthorize("@ss.hasPermi('system:publisher:add')")
    @Log(title = "邮贝发行方信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Publisher postPublisher)
    {
        return toAjax(iPublisherService.insertPostPublisher(postPublisher));
    }

    /**
     * 修改邮贝发行方信息
     */
    @PreAuthorize("@ss.hasPermi('system:publisher:edit')")
    @Log(title = "邮贝发行方信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Publisher postPublisher)
    {
        return toAjax(iPublisherService.updatePostPublisher(postPublisher));
    }

    /**
     * 删除邮贝发行方信息
     */
    @PreAuthorize("@ss.hasPermi('system:publisher:remove')")
    @Log(title = "邮贝发行方信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{publisherIds}")
    public AjaxResult remove(@PathVariable Long[] publisherIds)
    {
        return toAjax(iPublisherService.deletePostPublisherByPublisherIds(publisherIds));
    }

}
