package com.ruoyi.web.controller.post;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.constant.UserConstants;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.post.domain.PostCollection;
import com.ruoyi.post.service.IPostCollectionService;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.post.domain.PostSeries;
import com.ruoyi.post.service.IPostSeriesService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 邮贝套系信息;
 *
 * @author huianan
 * @date 2023-02-11
 */
@RestController
@RequestMapping("/post/series")
public class PostSeriesController extends BaseController {
    @Autowired
    private IPostSeriesService postSeriesService;

    @Autowired
    private IPostCollectionService postCollectionService;

    /**
     * 查询邮贝套系信息;
     */
    @ApiOperation("查询邮贝套系信息")
    @PreAuthorize("@ss.hasPermi('system:series:list')")
    @GetMapping("/list")
    public TableDataInfo list(PostSeries postSeries) {
        startPage();
        List<PostSeries> list = postSeriesService.selectPostSeriesList(postSeries);
        return getDataTable(list);
    }

    /**
     * 查询当前邮贝套系所含藏品信息;
     */
    @ApiOperation("查询套系所含藏品信息")
    @PreAuthorize("@ss.hasPermi('system:series:list')")
    @GetMapping("/list/{seriesId}")
    public TableDataInfo listCollection(@PathVariable("seriesId") Long seriesId, PostCollection postCollection) {
        startPage();
        PostSeries postSeries = postSeriesService.selectPostSeriesBySeriesId(seriesId);
        //获取对应匹配的套系昵称
        String seriesName = postSeries.getSeriesName();
        //通过匹配查询出对应的藏品
        postCollection.setSeriesName(seriesName);
        List<PostCollection> postCollections = postCollectionService.selectPostCollectionList(postCollection);
        return getDataTable(postCollections);
    }

    /**
     * 产品上链，
     * 不允许修改套系内藏品信息，也不允许新加藏品，
     * 获取到该所含藏品的套系名然后找到该套系的exchang_flag 是否为1 如果为1则在套系修改添加处增加限制条件
     *
     * 不允许再次上链，不允许删除，允许修改套系信息，其中“时间”只允许修改截止时间，且只能可以像当前截止时间之后设置；
     * 不允许二次上链，并且不能删除该套系
     * 时间只允许修改截止时间 并且修改的时间只能是当前时间之后
     *
     */

    /**
     * 查询邮贝在售套系信息;
     */
    @ApiOperation("查询套系所含在售藏品信息")
    @PreAuthorize("@ss.hasPermi('system:series:list')")
    @GetMapping("/sale")
    public TableDataInfo Sale(PostSeries postSeries) {
        startPage();
        List<PostSeries> list = postSeriesService.selectPostSeriesSale(postSeries);
        return getDataTable(list);
    }

    /**
     * 查询邮贝预售套系信息;
     */
    @ApiOperation("查询套系所含预售藏品信息")
    @PreAuthorize("@ss.hasPermi('system:series:list')")
    @GetMapping("/presale")
    public TableDataInfo PreSale(PostSeries postSeries) {
        startPage();
        List<PostSeries> list = postSeriesService.selectPostSeriesPreSale(postSeries);
        return getDataTable(list);
    }


    /**
     * 查询邮贝过期套系信息;
     */
    @ApiOperation("查询套系所含过期藏品信息")
    @PreAuthorize("@ss.hasPermi('system:series:list')")
    @GetMapping("/overdue")
    public TableDataInfo Overdue(PostSeries postSeries) {
        startPage();
        List<PostSeries> list = postSeriesService.selectPostSeriesOverdue(postSeries);
        return getDataTable(list);
    }

    /**
     * 上链功能;
     */
    @ApiOperation("套系上链")
    @PreAuthorize("@ss.hasPermi('system:series:list')")
    @GetMapping(value = "/onchain/{seriesId}")
    public AjaxResult OnChain(@PathVariable("seriesId") Long seriesId) {
        PostSeries postSeries = postSeriesService.selectPostSeriesBySeriesId(seriesId);
        if (postSeries == null) {
            return AjaxResult.error("套系为空");
        }
        System.out.println(postSeries.getExchangeFlag());
        int exchangeFlag = Integer.parseInt(postSeries.getExchangeFlag());
        if (exchangeFlag==1) {
            return AjaxResult.error("不可重复上链");
        }
        postSeriesService.OnChain(postSeries);
        return toAjax(1);
    }

    /**
     * 导出邮贝套系信息;
     */
    @PreAuthorize("@ss.hasPermi('system:series:export')")
    @Log(title = "邮贝套系信息; ", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PostSeries postSeries) {
        List<PostSeries> list = postSeriesService.selectPostSeriesList(postSeries);
        ExcelUtil<PostSeries> util = new ExcelUtil<PostSeries>(PostSeries.class);
        util.exportExcel(response, list, "邮贝套系信息; ");
    }

    /**
     * 获取邮贝套系信息; 详细信息
     */
    @ApiOperation("查询套系详细信息")
    @PreAuthorize("@ss.hasPermi('system:series:query')")
    @GetMapping(value = "/{seriesId}")
    public AjaxResult getInfo(@PathVariable("seriesId") Long seriesId) {
        return success(postSeriesService.selectPostSeriesBySeriesId(seriesId));
    }

    /**
     * 新增邮贝套系信息;
     */
    @ApiOperation("新增套系信息")
    @PreAuthorize("@ss.hasPermi('system:series:add')")
    @Log(title = "邮贝套系信息; ", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    public AjaxResult add(@RequestBody PostSeries postSeries) {
        if (postSeries.getExchangeFlag().equals("1")) {
            return AjaxResult.error("新增套系消息" + postSeries.getSeriesName() + "失败，套系已经上链");
        }

        if (UserConstants.NOT_UNIQUE.equals(postSeriesService.checkSeriesNameUnique(postSeries))) {
            return AjaxResult.error("新增套系消息" + postSeries.getSeriesName() + "失败，套系已经存在");
        }
        postSeries.setCreateBy(getUsername());
        /**
         * 根据套系时间，自动识别套系藏品所在table“在售/预售/以过期”根据当前时间，
         * 对比套系时间，当前小于套系时间，该套系藏品为“以过期”， 当前时间大于套系时间为“预售”
         */
        Date nowDate = new Date();
        nowDate = DateUtils.getNowDate();
        /**
         * 展示时间 结束时间
         * 当前时间大于结束时间  过期 2
         * 当前时间在展示时间以及结束时间区间 在售 0
         * 当前时间小于展示时间 预售 1
         */
        if (nowDate.compareTo(postSeries.getEndTime()) > 0) {
            postSeries.setStatus(String.valueOf(2));
        } else if (postSeries.getStartTime().compareTo(nowDate) > 0) {
            postSeries.setStatus(String.valueOf(1));
        } else {
            postSeries.setStatus(String.valueOf(0));
        }
        return toAjax(postSeriesService.insertPostSeries(postSeries));
    }

    /**
     * 修改邮贝套系信息;
     */
    @ApiOperation("修改套系信息")
    @PreAuthorize("@ss.hasPermi('system:series:edit')")
    @Log(title = "邮贝套系信息; ", businessType = BusinessType.UPDATE)
    @PutMapping("/edit")
    public AjaxResult edit(@RequestBody PostSeries postSeries) {
        //只能进行时间的后面修改
        if (postSeries.getExchangeFlag().equals("1")) {
            return AjaxResult.error("修改套系消息" + postSeries.getSeriesName() + "失败，套系已经上链");
        }

//        if (UserConstants.NOT_UNIQUE.equals(postSeriesService.checkSeriesNameUnique(postSeries))) {
//            return AjaxResult.error("修改套系消息" + postSeries.getSeriesName() + "失败，套系已经存在");
//        }
        postSeries.setUpdateBy(getUsername());
        Date nowDate = new Date();
        nowDate = DateUtils.getNowDate();
        /**
         * 展示时间 结束时间
         * 当前时间大于结束时间  过期 2
         * 当前时间在展示时间以及结束时间区间 在售 0
         * 当前时间小于展示时间 预售 1
         */
        if (nowDate.compareTo(postSeries.getEndTime()) > 0) {
            postSeries.setStatus(String.valueOf(2));
        } else if (postSeries.getStartTime().compareTo(nowDate) > 0) {
            postSeries.setStatus(String.valueOf(1));
        } else {
            postSeries.setStatus(String.valueOf(0));
        }
        return toAjax(postSeriesService.updatePostSeries(postSeries));
    }

    /**
     * 删除邮贝套系信息;
     */
    @ApiOperation("删除套系信息")
    @PreAuthorize("@ss.hasPermi('system:series:remove')")
    @Log(title = "邮贝套系信息; ", businessType = BusinessType.DELETE)
    @DeleteMapping("/{seriesIds}")
    public AjaxResult remove(@PathVariable Long[] seriesIds) {

        for (int i = 0; i < seriesIds.length; i++) {

            PostSeries postSeries = postSeriesService.selectPostSeriesBySeriesId(seriesIds[i]);
            if (postSeries == null) {
                return AjaxResult.error("套系内容为空");
            }

            if (postSeries.getExchangeFlag().equals("1")) {
                return AjaxResult.error("删除套系消息" + postSeries.getSeriesName() + "失败，套系已经上链");
            }
        }

        return toAjax(postSeriesService.deletePostSeriesBySeriesIds(seriesIds));
    }


}
